tree-sitter-hlsl
==================

[![CI][ci]](https://github.com/tree-sitter-grammars/tree-sitter-hlsl/actions/workflows/ci.yml)
[![discord][discord]](https://discord.gg/w7nTvsVJhm)
[![matrix][matrix]](https://matrix.to/#/#tree-sitter-chat:matrix.org)
[![npm][npm]](https://www.npmjs.com/package/tree-sitter-hlsl)
[![crates][crates]](https://crates.io/crates/tree-sitter-hlsl)
[![pypi][pypi]](https://pypi.org/project/tree-sitter-hlsl)

This is a extension of [tree-sitter-cpp](https://github.com/tree-sitter/tree-sitter-cpp) to support
the syntax of HLSL (https://docs.microsoft.com/en-us/windows/win32/direct3dhlsl/dx-graphics-hlsl).

[ci]: https://img.shields.io/github/actions/workflow/status/tree-sitter-grammars/tree-sitter-hlsl/ci.yml?logo=github&label=CI
[discord]: https://img.shields.io/discord/1063097320771698699?logo=discord&label=discord
[matrix]: https://img.shields.io/matrix/tree-sitter-chat%3Amatrix.org?logo=matrix&label=matrix
[npm]: https://img.shields.io/npm/v/tree-sitter-hlsl?logo=npm
[crates]: https://img.shields.io/crates/v/tree-sitter-hlsl?logo=rust
[pypi]: https://img.shields.io/pypi/v/tree-sitter-hlsl?logo=pypi&logoColor=ffd242
